/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.model;

import org.netbeans.api.project.Project;

/**
 *
 * @author johan
 */
public class AgroURIFactory {
    
    private final String baseURI;
    
    public AgroURIFactory(IssuingAgency issuingAgency, String enterpriseId) {
        assert issuingAgency != null;
        assert enterpriseId != null;                
        this.baseURI = issuingAgency.name() + "/" + enterpriseId + "/";
    }
    
    // create factory using e.g a Farm or an existing URI
    public AgroURIFactory(EnterpriseIdProvider enterpriseIdProvider) {
        this(enterpriseIdProvider.getIssuingAgency(), enterpriseIdProvider.getEnterpriseId());
    }
            
    public AgroURI createURI(ItemIdType itemIdType, String itemIdNumber) {
        assert itemIdType != null;
        assert itemIdNumber != null;
        
        if (!isValidItemIdNumber(itemIdNumber)) {
            throw new IllegalArgumentException("invalid ItemIdNumber");// TODO: to bundle
        }
        
        StringBuilder sb = new StringBuilder(baseURI)
                .append(itemIdType.name()).append("/").append(itemIdNumber);
        return new AgroURI(sb.toString());
    }

    public AgroURI createURI(ItemIdType itemIdType) {
        assert itemIdType != null;
        long id = EntityIdGenerator.Locator.getInstance().generateId(itemIdType);
        return createURI(itemIdType, Long.toString(id));
    }
    
    void validate() {
        
    }
        
    /**
     * validate itemIdNumber format.
     * EDI-teelt++ spec: an..14
     * @param itemIdNumber
     * @return 
     */
    boolean isValidItemIdNumber(String itemIdNumber) {
        if (itemIdNumber == null || itemIdNumber.equals("")) {
            return false;
        }
        
        //TODO: use pattern; spec needs clarification: example includes non alphanumeric character '.'
        int len = itemIdNumber.length();
        return len > 0 && len <= 14;
    }
    
    public static AgroURIFactory create(Project project) {
        EnterpriseIdProvider eip = project.getLookup().lookup(EnterpriseIdProvider.class);
        if (eip == null) {
            throw new RuntimeException("FIXME: Project should have an EnterpriseIdProvider in its lookup");
        }
        return new AgroURIFactory(eip);
    }
    
}
