/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.model;

import org.netbeans.api.project.Project;
import org.netbeans.api.project.ui.OpenProjects;
import org.openide.util.Lookup;

/**
 * Shared namespace for all entities within a single company/project/farm.
 * based on first two fields of URI path.
 *
 * @author johan
 */
public interface EnterpriseIdProvider {
    IssuingAgency getIssuingAgency();
    String getEnterpriseId();
    
    public static abstract class ProjectFinder {
        public static ProjectFinder getDefault() {
            ProjectFinder finder = Lookup.getDefault().lookup(ProjectFinder.class);
            if (finder == null) {
                finder = new OpenProjectFinder();
            }
            return finder;
        }
        
        public static Project find(EnterpriseIdProvider eip) {
            return getDefault().findProject(eip);
        }
        
        public abstract Project findProject(EnterpriseIdProvider eip);
    }
    
    public static class OpenProjectFinder extends ProjectFinder{

        @Override
        public Project findProject(EnterpriseIdProvider eip) {
            for (Project project : OpenProjects.getDefault().getOpenProjects()) {
                EnterpriseIdProvider projectEip = project.getLookup().lookup(EnterpriseIdProvider.class);
                if (projectEip != null &&
                        projectEip.getIssuingAgency() == eip.getIssuingAgency() &&
                        projectEip.getEnterpriseId().equals(eip.getEnterpriseId())) {
                    return project;
                }
            }
            return null;
        }
    }
    
    public static class Util {
        
        public static boolean isSameFarm(EnterpriseIdProvider eip1, EnterpriseIdProvider eip2) {
            if (eip1 == null || eip2 == null) {
                return false;
            }
            return eip1.getIssuingAgency() == eip2.getIssuingAgency()
                    && eip1.getEnterpriseId().equals(eip2.getEnterpriseId());
        }
        
        public static boolean isSameFarm(Entity e1, Entity e2) {
            if (e1 == null || e2 == null) {
                return false;
            }
            return isSameFarm(e1.getURI(), e2.getURI());
        }
    }
}
