/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.model;

import java.awt.Component;
import java.awt.Graphics;
import javax.swing.Icon;
import org.netbeans.spi.actions.AbstractSavable;

/**
 * adds a FarmID to AbstractSavable so we can filter by farm/project.
 * 
 * @author johan
 */
public abstract class EntitySavable extends AbstractSavable implements Icon {
    private final FarmID farmID;
    private final Icon icon;
    
    public EntitySavable(Entity entity, Icon icon) {
        this.farmID = new FarmID(entity.getURI());
        this.icon = icon;
    }
    
    public FarmID getFarmID() {
        return farmID;
    }
    
    // cancel save: unregister and remove from lookups
    public abstract void destroy();

    // optionally dispose enclosing object
    // e.g. dispose/invalidate dataobject upon closing project.
    public void dispose() {}
    
    @Override
    public void paintIcon(Component c, Graphics g, int x, int y) {
        icon.paintIcon(c, g, x, y);
    }

    @Override
    public int getIconWidth() {
        return icon.getIconWidth();
    }

    @Override
    public int getIconHeight() {
        return icon.getIconHeight();
    }
}
