/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.model;

import java.io.Serializable;
import java.util.Objects;

/**
 * composite key for the first two fields of an AgroURI.
 * 
 * @author johan
 */
public class FarmID implements Serializable, EnterpriseIdProvider {
    private static final long serialVersionUID = 1L;
    private final IssuingAgency agency;
    private final String id;

    public FarmID(EnterpriseIdProvider eip) {
        this.agency = eip.getIssuingAgency();
        this.id = eip.getEnterpriseId();
    }
    
    @Override
    public IssuingAgency getIssuingAgency() {
        return agency;
    }

    @Override
    public String getEnterpriseId() {
        return id;
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 53 * hash + (this.agency != null ? this.agency.hashCode() : 0);
        hash = 53 * hash + Objects.hashCode(this.id);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final FarmID other = (FarmID) obj;
        if (this.agency != other.agency) {
            return false;
        }
        if (!Objects.equals(this.id, other.id)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "FarmID{" + "agency=" + agency + ", id=" + id + '}';
    }
    
}
