/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.model;

import org.openide.util.NbPreferences;
import org.openide.util.lookup.ServiceProvider;

/**
 * Simple implementation of an EntityIdGenerator.
 * 
 * Stores last generated id in module preferences.
 * Clearing the user directory or fresh installation will reset the
 * id.
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
@ServiceProvider(service=EntityIdGenerator.class)
public class SimpleEntityIdGenerator implements EntityIdGenerator {
    
    private static final String PREF_LAST_GENERATED_ID = "lastGeneratedId";

    @Override
    public long generateId(ItemIdType itemIdType) {
        return generateId(itemIdType.name());
    }

    @Override
    public long generateId(String key) {
        long lastId = getLastId(key);
        lastId++;
        NbPreferences.forModule(this.getClass()).putLong(PREF_LAST_GENERATED_ID + key, lastId);
        return lastId;
    }
    
    private long getLastId(String key) {
        return NbPreferences.forModule(this.getClass()).getLong(PREF_LAST_GENERATED_ID + key, 0l);
    }
    
}
